@@ -1,31 +1,31 @@
 # logLikFit: Get a log likelihood ratio based on the fit indices
 
-likRatioFit <- function(outMod1, outMod2, dat1Mod1, dat1Mod2, dat2Mod1, dat2Mod2, 
+likRatioFit <- function(outMod1, outMod2, dat1Mod1, dat1Mod2, dat2Mod1, dat2Mod2,
     usedFit = NULL, prior = 1) {
 	usedFit <- cleanUsedFit(usedFit, colnames(dat1Mod1@fit), colnames(dat1Mod2@fit), colnames(dat2Mod1@fit), colnames(dat2Mod2@fit))
-    
-    observedFit <- as.data.frame(rbind(inspect(outMod1, "fit"), inspect(outMod2, "fit"))[, 
-        usedFit])
-    
-    mod1 <- clean(dat1Mod1, dat1Mod2, dat2Mod1, dat2Mod2)
-    dat1Mod1 <- mod1[[1]]
-    dat1Mod2 <- mod1[[2]]
-    mod2 <- clean(dat2Mod1, dat2Mod2)
-    dat2Mod1 <- mod2[[1]]
-    dat2Mod2 <- mod2[[2]]
-    dat1Mod1Fit <- as.data.frame(dat1Mod1@fit[, usedFit])
-    dat1Mod2Fit <- as.data.frame(dat1Mod2@fit[, usedFit])
-    dat2Mod1Fit <- as.data.frame(dat2Mod1@fit[, usedFit])
-    dat2Mod2Fit <- as.data.frame(dat2Mod2@fit[, usedFit])
-    
-    histDat1 <- mapply(find2Dhist, vec1 = dat1Mod1Fit, vec2 = dat1Mod2Fit, SIMPLIFY = FALSE)
-    histDat2 <- mapply(find2Dhist, vec1 = dat2Mod1Fit, vec2 = dat2Mod2Fit, SIMPLIFY = FALSE)
-    
-    likDat1 <- mapply(findphist, observedFit, histDat1)
-    likDat2 <- mapply(findphist, observedFit, histDat2)
-    likDat1[likDat1 == 0] <- 1e-07
-    likDat2[likDat2 == 0] <- 1e-07
-    (likDat1/likDat2) * prior
+
+  observedFit <- as.data.frame(rbind(lavInspect(outMod1, "fit"),
+                                     lavInspect(outMod2, "fit"))[,usedFit])
+
+  mod1 <- clean(dat1Mod1, dat1Mod2, dat2Mod1, dat2Mod2)
+  dat1Mod1 <- mod1[[1]]
+  dat1Mod2 <- mod1[[2]]
+  mod2 <- clean(dat2Mod1, dat2Mod2)
+  dat2Mod1 <- mod2[[1]]
+  dat2Mod2 <- mod2[[2]]
+  dat1Mod1Fit <- as.data.frame(dat1Mod1@fit[, usedFit])
+  dat1Mod2Fit <- as.data.frame(dat1Mod2@fit[, usedFit])
+  dat2Mod1Fit <- as.data.frame(dat2Mod1@fit[, usedFit])
+  dat2Mod2Fit <- as.data.frame(dat2Mod2@fit[, usedFit])
+
+  histDat1 <- mapply(find2Dhist, vec1 = dat1Mod1Fit, vec2 = dat1Mod2Fit, SIMPLIFY = FALSE)
+  histDat2 <- mapply(find2Dhist, vec1 = dat2Mod1Fit, vec2 = dat2Mod2Fit, SIMPLIFY = FALSE)
+
+  likDat1 <- mapply(findphist, observedFit, histDat1)
+  likDat2 <- mapply(findphist, observedFit, histDat2)
+  likDat1[likDat1 == 0] <- 1e-07
+  likDat2[likDat2 == 0] <- 1e-07
+  (likDat1/likDat2) * prior
 }
 
 # \title{
@@ -35,14 +35,14 @@ likRatioFit <- function(outMod1, outMod2, dat1Mod1, dat1Mod2, dat2Mod1, dat2Mod2
 	# Find the density (likelihood) of a pair value in 2D Kernel Density Estimate
 # }
 # \usage{
-# findphist(value, hist) 
+# findphist(value, hist)
 # }
 # \arguments{
   # \item{value}{
 	# A target pair of values
 # }
   # \item{hist}{
-	# A 2D Binned Kernel Density Estimate 
+	# A 2D Binned Kernel Density Estimate
 # }
 # }
 # \value{
@@ -81,7 +81,7 @@ findphist <- function(value, hist) {
 	# Fit the 2D Kernel Density Estimate to a pair of variables
 # }
 # \usage{
-# find2Dhist(vec1, vec2) 
+# find2Dhist(vec1, vec2)
 # }
 # \arguments{
   # \item{vec1}{
@@ -97,7 +97,7 @@ findphist <- function(value, hist) {
 
 find2Dhist <- function(vec1, vec2, gridsize = c(51L, 51L)) {
     result <- NA
-    try(result <- suppressWarnings(KernSmooth::bkde2D(cbind(vec1, vec2), c(KernSmooth::dpik(vec1), KernSmooth::dpik(vec2)), gridsize = gridsize)), 
+    try(result <- suppressWarnings(KernSmooth::bkde2D(cbind(vec1, vec2), c(KernSmooth::dpik(vec1), KernSmooth::dpik(vec2)), gridsize = gridsize)),
         silent = TRUE)
     return(result)
-} 
+}
